==> yanmah2-0.1-noarch.zip: about.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2009 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"; ?>
<?php
define("HELLO","world");
require_once "configurable_variables.php";
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<?php echo "<title>{$product_name_abbr} について - {$site_name}</title>\n"; ?>
	<link rel="stylesheet" href="./found.css" />
</head>
<body>
<?php
echo "<h1>{$product_name_abbr} について</h1>";
echo "<p>{$product_name_abbr}({$product_name_full})は、はてなのミニブログ「<a href=\"{$haiku_official_url}\">はてなハイク</a>」のコンテンツを携帯端末向けに小さく表示する PHP プログラムです。低速回線や処理性能に余裕がない端末でも、ハイクをサクサクと読めるように設計されています。このウェブサイトには、<a href=\"{$admin_url}\">{$admin_name}</a> が設置・管理しています。現在ここで動作している {$product_name_abbr} のヴァージョンは、{$product_version} です。</p>\n";
echo "<p>{$product_name_abbr} は、フリーソフトウェアライセンスである Affero GPL v3 の条件下で使用許諾されています。あなたは、<a href=\"{$project_url}\">{$project_name}</a> から {$product_name_abbr} のソースコードを入手し、 Affero GPL v3 の条件下で自由に利用、改変、再配布を行うことができます。{$project_name} では {$product_name_abbr} に関する文書を公開し、要望やバグ報告なども受け付けています。</p>\n";
echo "<p>このサイトに設置されている {$product_name_abbr} が、設置者により独自に改変されたものである場合、あなたは {$admin_name} からそのソースコードを受け取ることができます。</p>";
?>
<p><a href="./index.php">→インデックスへ戻る</a></p>
</body>
</html>

==> yanmah2-0.3-noarch.zip: about.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2009 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"; ?>
<?php
define("HELLO","world");
require_once "configurable_variables.php";
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$product_name_abbr} について - {$site_name}</title>\n"; ?>
	<link rel="stylesheet" href="./found.css" />
</head>
<body>
<?php
echo "<h1 id=\"about-head\" class=\"head1\">{$product_name_abbr} について</h1>\n";
echo "<div class=\"contents\"><p>{$product_name_abbr}({$product_name_full})は、はてなのミニブログ「<a href=\"{$haiku_official_url}\">はてなハイク</a>」のコンテンツを携帯端末向けに小さく表示する PHP プログラムです。低速回線や処理性能に余裕がない端末でも、ハイクをサクサクと読めるように設計されています。このウェブサイトには、<a href=\"{$admin_url}\">{$admin_name}</a> が設置・管理しています。現在ここで動作している {$product_name_abbr} のヴァージョンは、{$product_version} です。</p>\n";
echo "<p>{$product_name_abbr} は、フリーソフトウェアライセンスである Affero GPL v3 の条件下で使用許諾されています。あなたは、<a href=\"{$project_url}\">{$project_name}</a> から {$product_name_abbr} のソースコードを入手し、 Affero GPL v3 の条件下で自由に利用、改変、再配布を行うことができます。{$project_name} では {$product_name_abbr} に関する文書を公開し、要望やバグ報告なども受け付けています。</p>\n";
echo "<p>このサイトに設置されている {$product_name_abbr} が、設置者により独自に改変されたものである場合、あなたは {$admin_name} からそのソースコードを受け取ることができます。</p>";
?>
<p><a href="./index.php">→インデックスへ戻る</a></p>
</div>
<div class="access-analyzer">
<?php
echo $access_analyzer;
?>
</div>
</body>
</html>
